@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
@@ -7,22 +7,22 @@
 #include "grantleethememanager.h"
 #include "grantleetheme_p.h"
 
-#include <KDirWatch>
-#include <KSharedConfig>
-#include <KConfigGroup>
 #include <KActionCollection>
-#include <KToggleAction>
-#include <KLocalizedString>
-#include <KNS3/DownloadDialog>
-#include <KAuthorized>
 #include <KActionMenu>
+#include <KAuthorized>
+#include <KConfigGroup>
+#include <KDirWatch>
+#include <KLocalizedString>
+#include <KNewStuff3/KNS3/QtQuickDialogWrapper>
+#include <KSharedConfig>
+#include <KToggleAction>
 #include <QAction>
 #include <QIcon>
 #include <QPointer>
 
+#include <QActionGroup>
 #include <QDir>
 #include <QDirIterator>
-#include <QActionGroup>
 #include <QStandardPaths>
 
 using namespace GrantleeTheme;
@@ -74,17 +74,11 @@ public:
     {
         removeActions();
         themes.clear();
-        if (downloadThemesDialog) {
-            delete downloadThemesDialog.data();
-        }
     }
 
     void slotDownloadHeaderThemes()
     {
-        if (!downloadThemesDialog) {
-            downloadThemesDialog = new KNS3::DownloadDialog(downloadConfigFileName);
-        }
-        downloadThemesDialog.data()->show();
+        KNS3::QtQuickDialogWrapper(downloadConfigFileName).exec();
     }
 
     void directoryChanged()
@@ -197,7 +191,7 @@ public:
         }
         if (!themeActivatedFound) {
             if (!themesActionList.isEmpty() && !themeActivated.isEmpty()) {
-                //Activate first item if we removed theme.
+                // Activate first item if we removed theme.
                 KToggleAction *act = themesActionList.at(0);
                 act->setChecked(true);
                 selectTheme(act);
@@ -222,7 +216,7 @@ public:
     void slotThemeSelected()
     {
         if (q->sender()) {
-            auto *act = qobject_cast<KToggleAction *>(q->sender());
+            auto act = qobject_cast<KToggleAction *>(q->sender());
             selectTheme(act);
             Q_EMIT q->grantleeThemeSelected();
         }
@@ -267,11 +261,14 @@ public:
     QAction *separatorAction = nullptr;
 
     QAction *downloadThemesAction = nullptr;
-    QPointer<KNS3::DownloadDialog> downloadThemesDialog;
     ThemeManager *const q;
 };
 
-ThemeManager::ThemeManager(const QString &applicationType, const QString &defaultDesktopFileName, KActionCollection *actionCollection, const QString &path, QObject *parent)
+ThemeManager::ThemeManager(const QString &applicationType,
+                           const QString &defaultDesktopFileName,
+                           KActionCollection *actionCollection,
+                           const QString &path,
+                           QObject *parent)
     : QObject(parent)
     , d(new Private(applicationType, defaultDesktopFileName, actionCollection, path, this))
 {
@@ -337,7 +334,7 @@ QString ThemeManager::pathFromThemes(const QString &themesRelativePath, const QS
     if (!themesRelativePath.isEmpty()) {
         themesDirectories = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, themesRelativePath, QStandardPaths::LocateDirectory);
         if (themesDirectories.count() < 2) {
-            //Make sure to add local directory
+            // Make sure to add local directory
             const QString localDirectory = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + themesRelativePath;
             if (!themesDirectories.contains(localDirectory)) {
                 themesDirectories.append(localDirectory);
