@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef GRANTLEETHEMEMANAGER_H
@@ -21,19 +9,28 @@
 
 #include "grantleetheme.h"
 #include "grantleetheme_export.h"
-#include <QObject>
 #include <QMap>
+#include <QObject>
 class QActionGroup;
 class KActionCollection;
 class KToggleAction;
 class KActionMenu;
 
-namespace GrantleeTheme {
+namespace GrantleeTheme
+{
+/**
+ * @brief The ThemeManager class
+ * @author Laurent montel <montel@kde.org>
+ */
 class GRANTLEETHEME_EXPORT ThemeManager : public QObject
 {
     Q_OBJECT
 public:
-    explicit ThemeManager(const QString &themeType, const QString &defaultDesktopFileName, KActionCollection *actionCollection = nullptr, const QString &path = QString(), QObject *parent = nullptr);
+    explicit ThemeManager(const QString &themeType,
+                          const QString &defaultDesktopFileName,
+                          KActionCollection *actionCollection = nullptr,
+                          const QString &path = QString(),
+                          QObject *parent = nullptr);
     ~ThemeManager();
 
     Q_REQUIRED_RESULT QMap<QString, GrantleeTheme::Theme> themes() const;
